@@ -9,11 +9,11 @@ pub struct Document {
 impl Document {
     pub fn open(params: lsp::DidOpenTextDocumentParams) -> Self {
         let content = ropey::Rope::from(params.text_document.text);
-        let content = content.clone();
+        let content = content;
         Self { content }
     }
 
-    pub fn text(&self) -> ropey::Rope {
-        self.content.clone()
-    }
+    //pub fn text(&self) -> ropey::Rope {
+    //    self.content.clone()
+    //}
 }
